declare function compress(data: ReadonlyArray<0 | 1>): Uint8Array;
declare function decompress(data: Uint8Array): Array<0 | 1>;

interface IHuffmanNode {
    value?: string;
    left?: IHuffmanNode;
    right?: IHuffmanNode;
}
declare type IHuffmanEncodedData = Array<0 | 1>;
declare type IHuffmanEncodingTable = Record<string, IHuffmanEncodedData>;
/**
 * Create a Huffman tree for the specified texts.
 */
declare function createHuffmanTree(text: string): IHuffmanNode;
/**
 * Build a HuffmanEncodingTable based on Huffman tree.
 * @param tree
 * @returns
 */
declare function buildEncodingTable(tree: IHuffmanNode): IHuffmanEncodingTable;
/**
 * Build a huffman tree based on HuffmanEncodingTable.
 * @param table
 * @returns
 */
declare function buildHuffmanTree(table: IHuffmanEncodingTable): IHuffmanNode;

/**
 * Encode texts through Huffman encode algorithm.
 * @param plaintext
 * @returns
 */
declare function encode(plaintext: string): {
    encodedData: IHuffmanEncodedData;
    encodingTable: IHuffmanEncodingTable;
    tree: IHuffmanNode;
};
/**
 * @param encodedData
 * @param tree
 * @returns
 */
declare function decode(encodedData: IHuffmanEncodedData, tree: IHuffmanNode): string;

declare const _default: {
    encode: typeof encode;
    decode: typeof decode;
    compress: typeof compress;
    decompress: typeof decompress;
    buildEncodingTable: typeof buildEncodingTable;
    createHuffmanTree: typeof createHuffmanTree;
    buildHuffmanTree: typeof buildHuffmanTree;
};

export { IHuffmanEncodedData, IHuffmanEncodingTable, IHuffmanNode, buildEncodingTable, buildHuffmanTree, compress, createHuffmanTree, decode, decompress, _default as default, encode };
